@@ -11,7 +11,7 @@ import json
 
 
 class BaseFunctions(SalureConnect):
-    def __init__(self, label: str, data_dir: str, certificate_file: str = None, key_file: str = None, debug: bool = False):
+    def __init__(self, label: str, data_dir: str, certificate_file: str = None, key_file: str = None, client_secret: str = None, debug: bool = False):
         """
         The SAP class is used to get the access token for the SAP connection.
         :param label: The label of the SAP connection in SalureConnect
@@ -22,22 +22,28 @@ class BaseFunctions(SalureConnect):
         super().__init__()
         credentials = self.get_system_credential(system='sap', label=label)
         self.base_url = credentials['base_url']
-        self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file)
+        self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
         self.data_dir = data_dir
         self.debug = debug
 
-    def get_authorization_headers(self, client_id, authorisation_url, certificate_file, key_file):
+    def get_authorization_headers(self, client_id, authorisation_url, certificate_file=None, key_file=None, client_secret=None):
         """
         Get the access token from the endpoint
         1) Visit salureconnect to get the base_url, autorisation_url and client_id
         2) Get the access token from the endpoint using the client_id and certificate files
         :return: returns the retrieved access_token
         """
-        client = BackendApplicationClient(client_id=client_id)
-        oauth = OAuth2Session(client=client)
-        token = oauth.fetch_token(token_url=authorisation_url,
-                                  include_client_id=True,
-                                  cert=(certificate_file, key_file))
+        if client_secret is not None:
+            # Get the access token with help of the client_secret
+            payload = f'grant_type=client_credentials&client_id={client_id}&client_secret={client_secret}'
+            headers = {'Content-Type': 'application/x-www-form-urlencoded'}
+            token = requests.post(authorisation_url, headers=headers, data=payload).json()
+        else:
+            client = BackendApplicationClient(client_id=client_id)
+            oauth = OAuth2Session(client=client)
+            token = oauth.fetch_token(token_url=authorisation_url,
+                                      include_client_id=True,
+                                      cert=(certificate_file, key_file))
         headers = {
             'Authorization': f'Bearer {token["access_token"]}',
             'Content-Type': 'application/json'
