@@ -8,7 +8,7 @@ class DelimitEndpoints:
         self.data_dir = data_dir
         self.debug = debug
 
-    def delimit_master_action(self, employee_id, start_date, end_date):
+    def delimit_master_action(self, employee_id, start_date, end_date, action_type, reason_for_action):
         """
         Delimit personal data
         :param employee_id: the ID of the employee you want to delimit
@@ -16,7 +16,7 @@ class DelimitEndpoints:
         :param end_date: the end date at which the record will be delimit
         :return: status
         """
-        data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}'"
+        data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}',Actiontype='{action_type}',Reasonforaction='{reason_for_action}'"
         response = self.base_class.delete_data(uri='MasterActionDel', filter=data_filter)
         response.raise_for_status()
         return response
