@@ -89,18 +89,16 @@ class PostEndpoints:
         :return: status code for request and optional error message
         """
         allowed_fields = ['last_name', 'first_name', 'name_prefix', 'second_name_prefix', 'middle_name', 'middle_name', 'initials', 'second_title',
-                          'date_of_birth', 'language', 'nationality', 'title', 'gender']
+                          'date_of_birth', 'language', 'nationality', 'title', 'gender', 'name_at_birth']
         required_fields = ['afas_employee_id', 'sap_employee_id', 'start_date', 'end_date']
 
         self.__check_fields(data=data, required_fields=required_fields, allowed_fields=allowed_fields)
 
         base_body = {
-            'PersonalData': {
-                "Afasemployeenumber": data["afas_employee_id"],
-                "Employeenumber": data["sap_employee_id"],
-                "Startdate": data["start_date"],
-                "Enddate": data["end_date"]
-            }
+            "Afasemployeenumber": data["afas_employee_id"],
+            "Employeenumber": data["sap_employee_id"],
+            "Startdate": data["start_date"],
+            "Enddate": data["end_date"]
         }
         fields_to_update = {}
 
@@ -108,6 +106,7 @@ class PostEndpoints:
         fields_to_update.update({"Lastname": data['last_name']}) if 'last_name' in data else fields_to_update
         fields_to_update.update({"Firstname": data['first_name']}) if 'first_name' in data else fields_to_update
         fields_to_update.update({"Nameprefix": data['name_prefix']}) if 'name_prefix' in data else fields_to_update
+        fields_to_update.update({"NameatBirth": data['name_at_birth']}) if 'name_at_birth' in data else fields_to_update
         fields_to_update.update({"Secondnameprefix": data['second_name_prefix']}) if 'second_name_prefix' in data else fields_to_update
         fields_to_update.update({"Middlename": data['middle_name']}) if 'middle_name' in data else fields_to_update
         fields_to_update.update({"Initials": data['initials']}) if 'initials' in data else fields_to_update
